#ifndef __appsettingsheader_h__
#define __appsettingsheader_h__

#include "../DasherCore/Parameters.h"

enum { 
  APP_BP_TIME_STAMP = END_OF_SPS, APP_BP_SHOW_TOOLBAR,
  APP_BP_SHOW_TOOLBAR_TEXT, APP_BP_SHOW_LARGE_ICONS, APP_BP_FIX_LAYOUT,
  APP_BP_COPY_ALL_ON_STOP,APP_BP_WINDOW_PAUSE,APP_BP_SPEECH_MODE, 
  APP_BP_KEYBOARD_MODE, END_OF_APP_BPS
};

enum { 
  APP_LP_FILE_ENCODING = END_OF_APP_BPS, APP_LP_EDIT_FONT_SIZE, APP_LP_EDIT_HEIGHT,
  APP_LP_EDIT_WIDTH, 
  APP_LP_SCREEN_WIDTH, APP_LP_SCREEN_HEIGHT, APP_LP_SCREEN_WIDTH_H, APP_LP_SCREEN_HEIGHT_H, APP_LP_STYLE, APP_LP_DOCK_STYLE, END_OF_APP_LPS
};

enum {
  APP_SP_EDIT_FONT = END_OF_APP_LPS, 
#ifndef DASHER_WINCE
  APP_SP_WINDOW_STATE, 
#endif
  END_OF_APP_SPS
};

#endif
